@@ -14,11 +14,6 @@ $finder = PhpCsFixer\Finder::create()
     ->in(__DIR__ . '/tests/_files')
     ->in(__DIR__ . '/tests/end-to-end')
     ->in(__DIR__ . '/tests/unit')
-    // *WithPropertyWith*Hook.php use PHP 8.4 syntax that currently leads to PHP-CS-Fixer errors
-    ->notName('ExtendableClassWithPropertyWithGetHook.php')
-    ->notName('ExtendableClassWithPropertyWithSetHook.php')
-    ->notName('InterfaceWithPropertyWithGetHook.php')
-    ->notName('InterfaceWithPropertyWithSetHook.php')
     // DeprecatedPhpFeatureTest.php must not use declare(strict_types=1);
     ->notName('DeprecatedPhpFeatureTest.php')
     // UseBaselineTest.php must not use declare(strict_types=1);
@@ -163,6 +158,7 @@ $config->setFinder($finder)
             ],
         ],
         'native_type_declaration_casing' => true,
+        'new_expression_parentheses' => true,
         'new_with_parentheses' => [
             'anonymous_class' => false,
             'named_class' => false,
