@@ -10,6 +10,7 @@
 namespace PHPUnit\Framework;
 
 use const PHP_EOL;
+use function array_any;
 use function array_keys;
 use function array_merge;
 use function array_reverse;
@@ -94,6 +95,7 @@ use PHPUnit\Util\Exporter;
 use PHPUnit\Util\Test as TestUtil;
 use ReflectionClass;
 use ReflectionException;
+use ReflectionMethod;
 use ReflectionObject;
 use SebastianBergmann\CodeCoverage\UnintentionallyCoveredCodeException;
 use SebastianBergmann\Comparator\Comparator;
@@ -135,7 +137,6 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
      * @var list<callable>
      */
     private ?array $backupGlobalExceptionHandlers   = null;
-    private ?bool $runClassInSeparateProcess        = null;
     private ?bool $runTestInSeparateProcess         = null;
     private bool $preserveGlobalState               = false;
     private bool $inIsolation                       = false;
@@ -312,7 +313,7 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
     {
         $buffer = sprintf(
             '%s::%s',
-            (new ReflectionClass($this))->getName(),
+            new ReflectionClass($this)->getName(),
             $this->methodName,
         );
 
@@ -366,7 +367,6 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
 
         IsolatedTestRunnerRegistry::run(
             $this,
-            $this->runClassInSeparateProcess && !$this->runTestInSeparateProcess,
             $this->preserveGlobalState,
             $this->requiresXdebug(),
         );
@@ -767,14 +767,6 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
         }
     }
 
-    /**
-     * @internal This method is not covered by the backward compatibility promise for PHPUnit
-     */
-    final public function setRunClassInSeparateProcess(bool $runClassInSeparateProcess): void
-    {
-        $this->runClassInSeparateProcess = $runClassInSeparateProcess;
-    }
-
     /**
      * @internal This method is not covered by the backward compatibility promise for PHPUnit
      */
@@ -987,6 +979,12 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
      */
     final protected function any(): AnyInvokedCountMatcher
     {
+        Event\Facade::emitter()->testTriggeredPhpunitDeprecation(
+            $this->testValueObjectForEvents,
+            'The any() invoked count expectation is deprecated and will be removed in PHPUnit 14. ' .
+            'Use a test stub instead or configure a real invocation count expectation.',
+        );
+
         return new AnyInvokedCountMatcher;
     }
 
@@ -1297,6 +1295,15 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
         throw $t;
     }
 
+    /**
+     * @param array<mixed> $testArguments
+     */
+    protected function invokeTestMethod(string $methodName, array $testArguments): mixed
+    {
+        /** @phpstan-ignore method.dynamicName */
+        return $this->{$methodName}(...$testArguments);
+    }
+
     /**
      * Returns the data set as a string compatible with the --filter CLI option.
      *
@@ -1328,8 +1335,7 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
         $this->startErrorLogCapture();
 
         try {
-            /** @phpstan-ignore method.dynamicName */
-            $testResult = $this->{$this->methodName}(...$testArguments);
+            $testResult = $this->invokeTestMethod($this->methodName, $testArguments);
 
             $this->verifyErrorLogExpectation();
         } catch (Throwable $exception) {
@@ -1346,6 +1352,7 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
             $this->stopErrorLogCapture();
         }
 
+        $this->emitEventForCustomTestMethodInvocation();
         $this->expectedExceptionWasNotRaised();
 
         return $testResult;
@@ -1354,7 +1361,11 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
     private function stripDateFromErrorLog(string $log): string
     {
         // https://github.com/php/php-src/blob/c696087e323263e941774ebbf902ac249774ec9f/main/main.c#L905
-        return preg_replace('/\[\d+-\w+-\d+ \d+:\d+:\d+ [^\r\n[\]]+?\] /', '', $log);
+        $result = preg_replace('/\[\d+-\w+-\d+ \d+:\d+:\d+ [^\r\n[\]]+?\] /', '', $log);
+
+        assert($result !== null);
+
+        return $result;
     }
 
     /**
@@ -1378,15 +1389,10 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
         foreach ($this->expectedUserDeprecationMessageRegularExpression as $deprecationExpectation) {
             $this->numberOfAssertionsPerformed++;
 
-            $expectedDeprecationTriggered = false;
-
-            foreach (DeprecationCollector::deprecations() as $deprecation) {
-                if (@preg_match($deprecationExpectation, $deprecation) > 0) {
-                    $expectedDeprecationTriggered = true;
-
-                    break;
-                }
-            }
+            $expectedDeprecationTriggered = array_any(
+                DeprecationCollector::deprecations(),
+                static fn (string $deprecation) => @preg_match($deprecationExpectation, $deprecation) > 0,
+            );
 
             if (!$expectedDeprecationTriggered) {
                 throw new ExpectationFailedException(
@@ -1406,9 +1412,24 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
     {
         $allowsMockObjectsWithoutExpectations = $this->allowsMockObjectsWithoutExpectations();
         $isPhpunitTestSuite                   = str_starts_with($this::class, 'PHPUnit\\');
+        $requireSealedMockObjects             = ConfigurationRegistry::get()->requireSealedMockObjects();
 
         foreach ($this->mockObjects as $mockObject) {
-            if (!$mockObject['mockObject']->__phpunit_hasMatchers()) {
+            $mockedType = $mockObject['type'];
+            $mockObject = $mockObject['mockObject'];
+
+            if ($requireSealedMockObjects &&
+                !$mockObject->__phpunit_getInvocationHandler()->isSealed()) {
+                Event\Facade::emitter()->testConsideredRisky(
+                    $this->valueObjectForEvents(),
+                    sprintf(
+                        'Mock object for %s has not been sealed',
+                        $mockedType,
+                    ),
+                );
+            }
+
+            if (!$mockObject->__phpunit_hasMatchers()) {
                 if (!$allowsMockObjectsWithoutExpectations && !$isPhpunitTestSuite) {
                     Event\Facade::emitter()->testTriggeredPhpunitNotice(
                         $this->testValueObjectForEvents,
@@ -1416,7 +1437,7 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
                             'No expectations were configured for the mock object for %s. ' .
                             'Consider refactoring your test code to use a test stub instead. ' .
                             'The #[AllowMockObjectsWithoutExpectations] attribute can be used to opt out of this check.',
-                            $mockObject['type'],
+                            $mockedType,
                         ),
                     );
                 }
@@ -1426,8 +1447,8 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
 
             $this->numberOfAssertionsPerformed++;
 
-            $mockObject['mockObject']->__phpunit_verify(
-                $this->shouldInvocationMockerBeReset($mockObject['mockObject']),
+            $mockObject->__phpunit_verify(
+                $this->shouldInvocationMockerBeReset($mockObject),
             );
         }
     }
@@ -1997,10 +2018,6 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
             return true;
         }
 
-        if ($this->runClassInSeparateProcess) {
-            return true;
-        }
-
         return ConfigurationRegistry::get()->processIsolation();
     }
 
@@ -2329,13 +2346,10 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
 
     private function isRegisteredFailure(Throwable $t): bool
     {
-        foreach (array_keys($this->failureTypes) as $failureType) {
-            if ($t instanceof $failureType) {
-                return true;
-            }
-        }
-
-        return false;
+        return array_any(
+            array_keys($this->failureTypes),
+            static fn (string $failureType) => $t instanceof $failureType,
+        );
     }
 
     /**
@@ -2467,6 +2481,23 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
         return MetadataRegistry::parser()->forClassAndMethod(static::class, $this->methodName)->isAllowMockObjectsWithoutExpectations()->isNotEmpty();
     }
 
+    private function emitEventForCustomTestMethodInvocation(): void
+    {
+        $reflector = new ReflectionMethod($this, 'invokeTestMethod');
+
+        if (self::class === $reflector->getDeclaringClass()->getName()) {
+            return;
+        }
+
+        Event\Facade::emitter()->testUsedCustomMethodInvocation(
+            $this->valueObjectForEvents(),
+            new Event\Code\ClassMethod(
+                $reflector->getDeclaringClass()->getName(),
+                'invokeTestMethod',
+            ),
+        );
+    }
+
     /**
      * Returns a builder object to create test stubs using a fluent interface.
      *
