@@ -17,7 +17,6 @@ use function serialize;
 use function sys_get_temp_dir;
 use function tempnam;
 use function unlink;
-use function unserialize;
 use function var_export;
 use PHPUnit\Event\NoPreviousThrowableException;
 use PHPUnit\Runner\CodeCoverage;
@@ -44,20 +43,10 @@ final class SeparateProcessTestRunner implements IsolatedTestRunner
      * @throws NoPreviousThrowableException
      * @throws ProcessIsolationException
      */
-    public function run(TestCase $test, bool $runEntireClass, bool $preserveGlobalState, bool $requiresXdebug): void
+    public function run(TestCase $test, bool $preserveGlobalState, bool $requiresXdebug): void
     {
         $class = new ReflectionClass($test);
 
-        if ($runEntireClass) {
-            $template = new Template(
-                __DIR__ . '/templates/class.tpl',
-            );
-        } else {
-            $template = new Template(
-                __DIR__ . '/templates/method.tpl',
-            );
-        }
-
         $bootstrap     = '';
         $constants     = '';
         $globals       = '';
@@ -113,6 +102,7 @@ final class SeparateProcessTestRunner implements IsolatedTestRunner
             'phar'                           => $phar,
             'filename'                       => $file,
             'className'                      => $class->getName(),
+            'methodName'                     => $test->name(),
             'collectCodeCoverageInformation' => $coverage,
             'data'                           => $data,
             'dataName'                       => $dataName,
@@ -129,9 +119,7 @@ final class SeparateProcessTestRunner implements IsolatedTestRunner
             'processResultFile'              => $processResultFile,
         ];
 
-        if (!$runEntireClass) {
-            $var['methodName'] = $test->name();
-        }
+        $template = new Template(__DIR__ . '/templates/method.tpl');
 
         $template->setVar($var);
 
