@@ -9,8 +9,6 @@
  */
 namespace PHPUnit\Logging\TestDox;
 
-use function assert;
-use function count;
 use Iterator;
 
 /**
@@ -44,7 +42,7 @@ final class TestResultCollectionIterator implements Iterator
 
     public function valid(): bool
     {
-        return $this->position < count($this->testResults);
+        return isset($this->testResults[$this->position]);
     }
 
     /**
@@ -57,8 +55,6 @@ final class TestResultCollectionIterator implements Iterator
 
     public function current(): TestResult
     {
-        assert(isset($this->testResults[$this->position]));
-
         return $this->testResults[$this->position];
     }
 
