@@ -9,11 +9,10 @@
  */
 namespace PHPUnit\Metadata;
 
-use function count;
 use Iterator;
 
 /**
- * @template-implements Iterator<int, Metadata>
+ * @template-implements Iterator<non-negative-int, Metadata>
  *
  * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
  */
@@ -23,6 +22,10 @@ final class MetadataCollectionIterator implements Iterator
      * @var list<Metadata>
      */
     private readonly array $metadata;
+
+    /**
+     * @var non-negative-int
+     */
     private int $position = 0;
 
     public function __construct(MetadataCollection $metadata)
@@ -37,9 +40,12 @@ final class MetadataCollectionIterator implements Iterator
 
     public function valid(): bool
     {
-        return $this->position < count($this->metadata);
+        return isset($this->metadata[$this->position]);
     }
 
+    /**
+     * @return non-negative-int
+     */
     public function key(): int
     {
         return $this->position;
