@@ -70,7 +70,6 @@ use PHPUnit\Framework\Attributes\RequiresPhpExtension;
 use PHPUnit\Framework\Attributes\RequiresPhpunit;
 use PHPUnit\Framework\Attributes\RequiresPhpunitExtension;
 use PHPUnit\Framework\Attributes\RequiresSetting;
-use PHPUnit\Framework\Attributes\RunClassInSeparateProcess;
 use PHPUnit\Framework\Attributes\RunInSeparateProcess;
 use PHPUnit\Framework\Attributes\RunTestsInSeparateProcesses;
 use PHPUnit\Framework\Attributes\Small;
@@ -357,13 +356,15 @@ final readonly class AttributeParser implements Parser
                 case RequiresPhp::class:
                     assert($attributeInstance instanceof RequiresPhp);
 
-                    $result[] = Metadata::requiresPhpOnClass(
-                        $this->requirement(
-                            $attributeInstance->versionRequirement(),
-                            $className,
-                        ),
+                    $requirement = $this->requirement(
+                        $attributeInstance->versionRequirement(),
+                        $className,
                     );
 
+                    if ($requirement !== null) {
+                        $result[] = Metadata::requiresPhpOnClass($requirement);
+                    }
+
                     break;
 
                 case RequiresPhpExtension::class:
@@ -389,13 +390,15 @@ final readonly class AttributeParser implements Parser
                 case RequiresPhpunit::class:
                     assert($attributeInstance instanceof RequiresPhpunit);
 
-                    $result[] = Metadata::requiresPhpunitOnClass(
-                        $this->requirement(
-                            $attributeInstance->versionRequirement(),
-                            $className,
-                        ),
+                    $requirement = $this->requirement(
+                        $attributeInstance->versionRequirement(),
+                        $className,
                     );
 
+                    if ($requirement !== null) {
+                        $result[] = Metadata::requiresPhpunitOnClass($requirement);
+                    }
+
                     break;
 
                 case RequiresPhpunitExtension::class:
@@ -437,11 +440,6 @@ final readonly class AttributeParser implements Parser
 
                     break;
 
-                case RunClassInSeparateProcess::class:
-                    $result[] = Metadata::runClassInSeparateProcess();
-
-                    break;
-
                 case RunTestsInSeparateProcesses::class:
                     $result[] = Metadata::runTestsInSeparateProcesses();
 
@@ -785,14 +783,16 @@ final readonly class AttributeParser implements Parser
                 case RequiresPhp::class:
                     assert($attributeInstance instanceof RequiresPhp);
 
-                    $result[] = Metadata::requiresPhpOnMethod(
-                        $this->requirement(
-                            $attributeInstance->versionRequirement(),
-                            $className,
-                            $methodName,
-                        ),
+                    $requirement = $this->requirement(
+                        $attributeInstance->versionRequirement(),
+                        $className,
+                        $methodName,
                     );
 
+                    if ($requirement !== null) {
+                        $result[] = Metadata::requiresPhpOnMethod($requirement);
+                    }
+
                     break;
 
                 case RequiresPhpExtension::class:
@@ -819,14 +819,16 @@ final readonly class AttributeParser implements Parser
                 case RequiresPhpunit::class:
                     assert($attributeInstance instanceof RequiresPhpunit);
 
-                    $result[] = Metadata::requiresPhpunitOnMethod(
-                        $this->requirement(
-                            $attributeInstance->versionRequirement(),
-                            $className,
-                            $methodName,
-                        ),
+                    $requirement = $this->requirement(
+                        $attributeInstance->versionRequirement(),
+                        $className,
+                        $methodName,
                     );
 
+                    if ($requirement !== null) {
+                        $result[] = Metadata::requiresPhpunitOnMethod($requirement);
+                    }
+
                     break;
 
                 case RequiresPhpunitExtension::class:
@@ -982,16 +984,18 @@ final readonly class AttributeParser implements Parser
      * @param class-string      $testClassName
      * @param ?non-empty-string $testMethodName
      */
-    private function requirement(string $versionRequirement, string $testClassName, ?string $testMethodName = null): Requirement
+    private function requirement(string $versionRequirement, string $testClassName, ?string $testMethodName = null): ?Requirement
     {
         if (is_numeric(trim($versionRequirement))) {
-            EventFacade::emitter()->testRunnerTriggeredPhpunitDeprecation(
+            EventFacade::emitter()->testRunnerTriggeredPhpunitWarning(
                 sprintf(
-                    'Test %s has attribute with version constraint string argument without explicit version comparison operator ("%s")',
+                    'Test %s has attribute with version constraint string argument without explicit version comparison operator ("%s"), version constraint is ignored',
                     $this->testAsString($testClassName, $testMethodName),
                     $versionRequirement,
                 ),
             );
+
+            return null;
         }
 
         return Requirement::from($versionRequirement);
