@@ -22,10 +22,9 @@ final readonly class RequiresOperatingSystem extends Metadata
     private string $operatingSystem;
 
     /**
-     * @param int<0, 1>        $level
      * @param non-empty-string $operatingSystem
      */
-    protected function __construct(int $level, string $operatingSystem)
+    protected function __construct(Level $level, string $operatingSystem)
     {
         parent::__construct($level);
 
