@@ -22,10 +22,9 @@ final readonly class UsesClassesThatImplementInterface extends Metadata
     private string $interfaceName;
 
     /**
-     * @param int<0, 1>    $level
      * @param class-string $interfaceName
      */
-    protected function __construct(int $level, string $interfaceName)
+    protected function __construct(Level $level, string $interfaceName)
     {
         parent::__construct($level);
 
