@@ -9,8 +9,6 @@
  */
 namespace PHPUnit\TextUI\Configuration;
 
-use function assert;
-use function count;
 use Iterator;
 
 /**
@@ -42,7 +40,7 @@ final class TestDirectoryCollectionIterator implements Iterator
 
     public function valid(): bool
     {
-        return $this->position < count($this->directories);
+        return isset($this->directories[$this->position]);
     }
 
     /**
@@ -55,8 +53,6 @@ final class TestDirectoryCollectionIterator implements Iterator
 
     public function current(): TestDirectory
     {
-        assert(isset($this->directories[$this->position]));
-
         return $this->directories[$this->position];
     }
 
