@@ -11,8 +11,10 @@ namespace PHPUnit\Util;
 
 use const DIRECTORY_SEPARATOR;
 use const PHP_EOL;
+use function array_key_exists;
 use function array_map;
 use function array_walk;
+use function assert;
 use function count;
 use function explode;
 use function implode;
@@ -80,17 +82,25 @@ final class Color
         'bg-white'   => '47',
     ];
 
+    /**
+     * @param non-empty-string $color
+     */
     public static function colorize(string $color, string $buffer): string
     {
         if (trim($buffer) === '') {
             return $buffer;
         }
 
-        $codes  = array_map('\trim', explode(',', $color));
+        if (array_key_exists($color, self::ANSI_CODES)) {
+            return self::optimizeColor(sprintf("\x1b[%sm%s\x1b[0m", self::ANSI_CODES[$color], $buffer));
+        }
+
         $styles = [];
 
-        foreach ($codes as $code) {
-            if (isset(self::ANSI_CODES[$code])) {
+        foreach (explode(',', $color) as $code) {
+            $code = trim($code);
+
+            if (array_key_exists($code, self::ANSI_CODES)) {
                 $styles[] = self::ANSI_CODES[$code];
             }
         }
@@ -99,13 +109,17 @@ final class Color
             return $buffer;
         }
 
-        return self::optimizeColor(sprintf("\x1b[%sm", implode(';', $styles)) . $buffer . "\x1b[0m");
+        return self::optimizeColor(sprintf("\x1b[%sm%s\x1b[0m", implode(';', $styles), $buffer));
     }
 
+    /**
+     * @param non-empty-string  $color
+     * @param ?non-negative-int $columns
+     */
     public static function colorizeTextBox(string $color, string $buffer, ?int $columns = null): string
     {
         $lines       = preg_split('/\r\n|\r|\n/', $buffer);
-        $maxBoxWidth = max(array_map('\strlen', $lines));
+        $maxBoxWidth = max(array_map(\strlen(...), $lines));
 
         if ($columns !== null) {
             $maxBoxWidth = min($maxBoxWidth, $columns);
@@ -119,6 +133,10 @@ final class Color
         return implode(PHP_EOL, $lines);
     }
 
+    /**
+     * @param non-empty-string  $path
+     * @param ?non-empty-string $previousPath
+     */
     public static function colorizePath(string $path, ?string $previousPath = null, bool $colorizeFilename = false): string
     {
         if ($previousPath === null) {
@@ -159,16 +177,20 @@ final class Color
     {
         $replaceMap = $visualizeEOL ? self::WHITESPACE_EOL_MAP : self::WHITESPACE_MAP;
 
-        return preg_replace_callback(
+        $result = preg_replace_callback(
             '/\s+/',
             static fn (array $matches) => self::dim(strtr($matches[0], $replaceMap)),
             $buffer,
         );
+
+        assert($result !== null);
+
+        return $result;
     }
 
     private static function optimizeColor(string $buffer): string
     {
-        return preg_replace(
+        $result = preg_replace(
             [
                 "/\e\\[22m\e\\[2m/",
                 "/\e\\[([^m]*)m\e\\[([1-9][0-9;]*)m/",
@@ -181,5 +203,9 @@ final class Color
             ],
             $buffer,
         );
+
+        assert($result !== null);
+
+        return $result;
     }
 }
