@@ -9,11 +9,11 @@
  */
 namespace PHPUnit\TestFixture\TestDox;
 
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\TestDox;
 use PHPUnit\Framework\TestCase;
 
-/**
- * @testdox Text from class-level TestDox metadata
- */
+#[TestDox('Text from class-level TestDox metadata')]
 final class DataProviderWithNumericDataSetNameAndMetadataWithPlaceholdersTest extends TestCase
 {
     public static function provider(): array
@@ -26,26 +26,21 @@ final class DataProviderWithNumericDataSetNameAndMetadataWithPlaceholdersTest ex
                 ['key' => 'value'],
                 true,
                 Foo::BAR,
+                Bar::FOO,
             ],
         ];
     }
 
-    /**
-     * @dataProvider provider
-     *
-     * @testdox Text from method-level TestDox metadata for successful test with placeholders ($a, $b, $c $d, $e, $f)
-     */
-    public function testSomethingThatWorks(string $a, int $b, float $c, array $d, bool $e, Foo $f): void
+    #[DataProvider('provider')]
+    #[TestDox('Text from method-level TestDox metadata for successful test with placeholders ($a, $b, $c, $d, $e, $f, $g)')]
+    public function testSomethingThatWorks(string $a, int $b, float $c, array $d, bool $e, Foo $f, Bar $g): void
     {
         $this->assertTrue(true);
     }
 
-    /**
-     * @dataProvider provider
-     *
-     * @testdox Text from method-level TestDox metadata for failing test with placeholders ($a, $b, $c $d, $e, $f)
-     */
-    public function testSomethingThatDoesNotWork(string $a, int $b, float $c, array $d, bool $e, Foo $f): void
+    #[DataProvider('provider')]
+    #[TestDox('Text from method-level TestDox metadata for failing test with placeholders ($a, $b, $c, $d, $e, $f, $g)')]
+    public function testSomethingThatDoesNotWork(string $a, int $b, float $c, array $d, bool $e, Foo $f, Bar $g): void
     {
         /* @noinspection PhpUnitAssertTrueWithIncompatibleTypeArgumentInspection */
         $this->assertTrue(false);
