@@ -13,10 +13,13 @@ use Exception;
 use PHPUnit\Event\AbstractEventTestCase;
 use PHPUnit\Event\Code;
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 
 #[CoversClass(PreConditionErrored::class)]
 #[Small]
+#[Group('event-system')]
+#[Group('event-system/events')]
 final class PreConditionErroredTest extends AbstractEventTestCase
 {
     public function testConstructorSetsValues(): void
@@ -35,7 +38,6 @@ final class PreConditionErroredTest extends AbstractEventTestCase
 
         $this->assertSame($telemetryInfo, $event->telemetryInfo());
         $this->assertSame($test, $event->test());
-        $this->assertSame('FooTest', $event->testClassName());
         $this->assertSame($calledMethod, $event->calledMethod());
         $this->assertSame($throwable, $event->throwable());
     }
