@@ -13,10 +13,13 @@ use const PHP_EOL;
 use PHPUnit\Event\AbstractEventTestCase;
 use PHPUnit\Event\Code\IssueTrigger\IssueTrigger;
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 
 #[CoversClass(DeprecationTriggered::class)]
 #[Small]
+#[Group('event-system')]
+#[Group('event-system/events')]
 final class DeprecationTriggeredTest extends AbstractEventTestCase
 {
     public function testConstructorSetsValues(): void
