@@ -12,10 +12,13 @@ namespace PHPUnit\Event\Test;
 use const PHP_EOL;
 use PHPUnit\Event\AbstractEventTestCase;
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 
 #[CoversClass(PhpunitNoticeTriggered::class)]
 #[Small]
+#[Group('event-system')]
+#[Group('event-system/events')]
 final class PhpunitNoticeTriggeredTest extends AbstractEventTestCase
 {
     public function testConstructorSetsValues(): void
