@@ -13,6 +13,7 @@ use function fclose;
 use function fopen;
 use PHPUnit\Framework\Attributes\CoversMethod;
 use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\TestDox;
 use stdClass;
@@ -20,6 +21,8 @@ use stdClass;
 #[CoversMethod(Assert::class, 'assertIsInt')]
 #[TestDox('assertIsInt()')]
 #[Small]
+#[Group('framework')]
+#[Group('framework/assertions')]
 final class assertIsIntTest extends TestCase
 {
     /**
