@@ -13,12 +13,15 @@ use function fclose;
 use function fopen;
 use PHPUnit\Framework\Attributes\CoversMethod;
 use PHPUnit\Framework\Attributes\DataProviderExternal;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\TestDox;
 
 #[CoversMethod(Assert::class, 'assertIsNotClosedResource')]
 #[TestDox('assertIsNotClosedResource()')]
 #[Small]
+#[Group('framework')]
+#[Group('framework/assertions')]
 final class assertIsNotClosedResourceTest extends TestCase
 {
     #[DataProviderExternal(assertIsClosedResourceTest::class, 'failureProvider')]
