@@ -11,12 +11,15 @@ namespace PHPUnit\Framework;
 
 use const NAN;
 use PHPUnit\Framework\Attributes\CoversMethod;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\TestDox;
 
 #[CoversMethod(Assert::class, 'assertNan')]
 #[TestDox('assertNan()')]
 #[Small]
+#[Group('framework')]
+#[Group('framework/assertions')]
 final class assertNanTest extends TestCase
 {
     public function testSucceedsWhenConstraintEvaluatesToTrue(): void
