@@ -11,12 +11,15 @@ namespace PHPUnit\Framework;
 
 use PHPUnit\Framework\Attributes\CoversMethod;
 use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\TestDox;
 
 #[CoversMethod(Assert::class, 'assertNotFalse')]
 #[TestDox('assertNotFalse()')]
 #[Small]
+#[Group('framework')]
+#[Group('framework/assertions')]
 final class assertNotFalseTest extends TestCase
 {
     /**
