@@ -11,6 +11,7 @@ namespace PHPUnit\Framework\Constraint;
 
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\ExpectationFailedException;
 use PHPUnit\Framework\TestCase;
@@ -18,6 +19,8 @@ use PHPUnit\Framework\TestCase;
 #[CoversClass(StringContains::class)]
 #[CoversClass(Constraint::class)]
 #[Small]
+#[Group('framework')]
+#[Group('framework/constraints')]
 final class StringContainsTest extends TestCase
 {
     public static function providesEvaluationCases(): array
@@ -225,7 +228,7 @@ final class StringContainsTest extends TestCase
     #[DataProvider('providesToStringRepresentationCases')]
     public function testCanBeRepresentedAsString(string $expected, string $needle, bool $ignoreCase, bool $ignoreLineEndings): void
     {
-        $this->assertSame($expected, (new StringContains($needle, $ignoreCase, $ignoreLineEndings))->toString());
+        $this->assertSame($expected, new StringContains($needle, $ignoreCase, $ignoreLineEndings)->toString());
     }
 
     public function testIsCountable(): void
