@@ -11,6 +11,7 @@ namespace PHPUnit\Framework\Constraint;
 
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\ExpectationFailedException;
 use PHPUnit\Framework\TestCase;
@@ -21,6 +22,8 @@ use stdClass;
 #[CoversClass(TraversableContains::class)]
 #[CoversClass(Constraint::class)]
 #[Small]
+#[Group('framework')]
+#[Group('framework/constraints')]
 final class TraversableContainsEqualTest extends TestCase
 {
     public static function provider(): array
@@ -108,7 +111,7 @@ final class TraversableContainsEqualTest extends TestCase
 
     public function testCanBeRepresentedAsString(): void
     {
-        $this->assertSame('contains \'value\'', (new TraversableContainsEqual('value'))->toString());
+        $this->assertSame('contains \'value\'', new TraversableContainsEqual('value')->toString());
     }
 
     public function testIsCountable(): void
