@@ -10,6 +10,7 @@
 namespace PHPUnit\TextUI\CliArguments;
 
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\TestDox;
 use PHPUnit\Framework\TestCase;
@@ -19,6 +20,9 @@ use PHPUnit\Runner\TestSuiteSorter;
 #[CoversClass(Configuration::class)]
 #[Small]
 #[TestDox('CLI Options Parser')]
+#[Group('textui')]
+#[Group('textui/configuration')]
+#[Group('textui/configuration/cli')]
 final class BuilderTest extends TestCase
 {
     #[TestDox('argument')]
@@ -29,6 +33,26 @@ final class BuilderTest extends TestCase
         $this->assertSame(['argument'], $configuration->arguments());
     }
 
+    #[TestDox('--test-files-file tests.txt')]
+    public function testTestFilesFile(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--test-files-file', 'tests.txt']);
+
+        $this->assertTrue($configuration->hasTestFilesFile());
+        $this->assertSame('tests.txt', $configuration->testFilesFile());
+    }
+
+    public function testTestFilesFileMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasTestFilesFile());
+
+        $this->expectException(Exception::class);
+
+        $configuration->testFilesFile();
+    }
+
     #[TestDox('--all')]
     public function testAll(): void
     {
