@@ -13,10 +13,13 @@ use function json_encode;
 use function sprintf;
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 
 #[CoversClass(SourceFilter::class)]
 #[Small]
+#[Group('textui')]
+#[Group('textui/configuration')]
 final class SourceFilterTest extends AbstractSouceFilterTestCase
 {
     public static function provider(): array
@@ -422,7 +425,7 @@ final class SourceFilterTest extends AbstractSouceFilterTestCase
             $this->assertFileExists($file);
             $this->assertSame(
                 $shouldInclude,
-                (new SourceFilter((new SourceMapper)->map($source)))->includes($file),
+                new SourceFilter((new SourceMapper)->map($source))->includes($file),
                 sprintf('expected match to return %s for: %s', json_encode($shouldInclude), $file),
             );
         }
